/* NOTE: THIS SCORE SHOWS A SOLUTION TO THE BUS PROBLEM USING THE CHAIN INSTRUMENT TO
   INTERNALLY CONNECT INSTRUMENTS TOGETHER WITHOUT NEED TO DEAL WITH AUX BUSSES
*/

rtsetparams(48000, 2);

rtinput("/Users/dscott/CLASSNEW/Willard-July27-1955.wav");	// read audio from this file

load("TRANS");	// these let me run the score from the command line
load("MOOGVCF");
load("CHAIN");

// TRANS reads from the input sound file and outputs to a CHAIN bus.

bus_config("TRANS", "in 0", "chain 0 out");

// MOOGVCF reads from that chain bus and sends to a pair of CHAIN busses.

bus_config("MOOGVCF", "chain 0 in", "chain 1-2 out");

// CHAIN sends its audio to the output.  Dont attempt to specific where it is reading
// from

bus_config("CHAIN", "out 0-1");

// Creating variables for all your instrument's arguments makes it easy to
// remember them.

///////////////////////////////////////////////////////////
////////////////////// FIRST EVENT ///////////////////////
// Starts at output time 0.  Duration 5 seconds.  Transpose down 1/2 octave.
// Filter at 1000 Hz.
///////////////////////////////////////////////////////////

// TRANS arguments
// TRANS(outsk, insk, dur, AMP, TRANSP[, inputchan, PAN])

outskip = 0;	// because TRANS writes to CHAIN, this is ALWAYS zero
start = 67;		// where TRANS will read from the input audio file
duration = 5;
gain = 1;		// the input file's samples are already in the +-32K range
envelope = maketable("line", 1000, 0,0, 1,1, 9,1, 10,0);
transp_interval = -0.06;	// transpose down 1/2 octave

// Create TRANS instrument "handle" for CHAIN
trans_inst = makeinstrument("TRANS", outskip, start, duration, gain*envelope, transp_interval);

// MOOGVCF arguments
// MOOGVCF(outsk, insk, dur, AMP, inputchan, PAN, BYPASS, FILTFREQTABLE, FILTRESONTABLE

outskip = 0;	// because MOOGVCF writes to CHAIN, this is ALWAYS zero
start = 0;		// because MOOGVCF reads from CHAIN, this is ALWAYS zero
moog_gain = 50;		// using this gain to adjust for MOOGVCF effect
cutoff_freq = 1000;
resonance = 0.9;
pan = 1;			// hard left

// Create MOOG instrument "handle" for CHAIN
moog_inst = makeinstrument("MOOGVCF", outskip, start, duration, moog_gain, inchan=0, pan, bypass=0, cutoff_freq, resonance);

// CHAIN arguments
// CHAIN(outsk, dur, number, handle1...n)

outskip = 0;	// because CHAIN writes to output, this is our real outskip
num_insts = 2;	// how many insts are we handing to CHAIN?

// NOW the call to chain will:
// transpose it!
// filter the result of that transpose
// write the audio to the output for 'duration' seconds

CHAIN(outskip, duration, num_insts, trans_inst, moog_inst);

///////////////////////////////////////////////////////////
////////////////////// SECOND EVENT ///////////////////////
// Starts at output time 2.  Duration 4 seconds.  Transpose up 1 octave.
// Filter at 400 Hz.  Different gain envelope.
///////////////////////////////////////////////////////////

// TRANS arguments
// TRANS(outsk, insk, dur, AMP, TRANSP[, inputchan, PAN])

outskip = 0;	// because TRANS writes to CHAIN, this is ALWAYS zero
start = 203;	// where TRANS will read from the input audio file
duration = 4;
gain = 1;		// the input file's samples are already in the +-32K range
envelope = maketable("line", 1000, 0,0, 1,1, 2,0);
transp_interval = 1.00;	// transpose up 1 octave

// Create TRANS instrument "handle" for CHAIN
trans_inst = makeinstrument("TRANS", outskip, start, duration, gain*envelope, transp_interval);

// MOOGVCF arguments
// MOOGVCF(outsk, insk, dur, AMP, inputchan, PAN, BYPASS, FILTFREQTABLE, FILTRESONTABLE

outskip = 0;		// because MOOGVCF writes to CHAIN, this is ALWAYS zero
start = 0;			// because MOOGVCF reads from CHAIN, this is ALWAYS zero
moog_gain = 400;	// using this gain to adjust for MOOGVCF effect
cutoff_freq = 400;
resonance = 0.9;
pan = 0;			// hard right

// Create MOOG instrument "handle" for CHAIN
moog_inst = makeinstrument("MOOGVCF", outskip, start, duration, moog_gain, inchan=0, pan, bypass=0, cutoff_freq, resonance);

// CHAIN arguments
// CHAIN(outsk, dur, number, handle1...n)

outskip = 2;	// because CHAIN writes to output, this is our real outskip
num_insts = 2;	// how many insts are we handing to CHAIN?

// NOW the call to chain will:
// transpose it!
// filter the result of that transpose
// write the audio to the output for 'duration' seconds

CHAIN(outskip, duration, num_insts, trans_inst, moog_inst);
